@@ -1,34 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Quick Controls module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL3$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
 ** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
 ** packaging of this file. Please review the following information to
 ** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl.html.
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or later as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file. Please review the following information to
-** ensure the GNU General Public License version 2.0 requirements will be
-** met: http://www.gnu.org/licenses/gpl-2.0.html.
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -51,13 +54,13 @@
 QT_BEGIN_NAMESPACE
 
 /*!
-  \class QQuickMenu
+  \class QQuickMenu1
   \internal
  */
 
 /*!
   \qmltype MenuPrivate
-  \instantiates QQuickMenu
+  \instantiates QQuickMenu1
   \internal
   \inqmlmodule QtQuick.Controls
  */
@@ -72,7 +75,7 @@ QT_BEGIN_NAMESPACE
     as children. It also supports \l Instantiator objects as long as the insertion is
     being done manually using \l insertItem().
 
-    \code
+    \qml
     Menu {
         id: recentFilesMenu
 
@@ -94,7 +97,8 @@ QT_BEGIN_NAMESPACE
             enabled: recentFilesModel.count > 0
             onTriggered: recentFilesModel.clear()
         }
-    \endcode
+    }
+    \endqml
 
     Note that in this case, the \c index parameter passed to \l insertItem() is relative
     to the position of the \l Instantiator in the menu, as opposed to absolute position
@@ -254,8 +258,9 @@ QT_BEGIN_NAMESPACE
     \sa aboutToShow()
 */
 
-QQuickMenu::QQuickMenu(QObject *parent)
-    : QQuickMenuText(parent, QQuickMenuItemType::Menu),
+QQuickMenu1::QQuickMenu1(QObject *parent)
+    : QQuickMenuText1(parent, QQuickMenuItemType1::Menu),
+      m_platformMenu(0),
       m_itemsCount(0),
       m_selectedIndex(-1),
       m_parentWindow(0),
@@ -265,25 +270,29 @@ QQuickMenu::QQuickMenu(QObject *parent)
       m_popupVisible(false),
       m_containersCount(0),
       m_xOffset(0),
-      m_yOffset(0)
+      m_yOffset(0),
+      m_triggerCount(0),
+      m_proxy(false)
 {
     connect(this, SIGNAL(__textChanged()), this, SIGNAL(titleChanged()));
 
-    m_platformMenu = QGuiApplicationPrivate::platformTheme()->createPlatformMenu();
-    if (m_platformMenu) {
-        connect(m_platformMenu, SIGNAL(aboutToShow()), this, SIGNAL(aboutToShow()));
-        connect(m_platformMenu, SIGNAL(aboutToHide()), this, SLOT(__closeMenu()));
-        if (platformItem())
-            platformItem()->setMenu(m_platformMenu);
+    if (QGuiApplication::platformName() != QStringLiteral("xcb")) { // QTBUG-51372
+        m_platformMenu = QGuiApplicationPrivate::platformTheme()->createPlatformMenu();
+        if (m_platformMenu) {
+            connect(m_platformMenu, SIGNAL(aboutToShow()), this, SIGNAL(aboutToShow()));
+            connect(m_platformMenu, SIGNAL(aboutToHide()), this, SLOT(hideMenu()));
+            if (platformItem())
+                platformItem()->setMenu(m_platformMenu);
+        }
     }
     if (const QFont *font = QGuiApplicationPrivate::platformTheme()->font(QPlatformTheme::MenuItemFont))
         m_font = *const_cast<QFont*>(font);
 }
 
-QQuickMenu::~QQuickMenu()
+QQuickMenu1::~QQuickMenu1()
 {
     while (!m_menuItems.empty()) {
-        QQuickMenuBase *item = m_menuItems.takeFirst();
+        QQuickMenuBase1 *item = m_menuItems.takeFirst();
         if (item)
             item->setParentMenu(0);
     }
@@ -295,39 +304,39 @@ QQuickMenu::~QQuickMenu()
     m_platformMenu = 0;
 }
 
-void QQuickMenu::syncParentMenuBar()
+void QQuickMenu1::syncParentMenuBar()
 {
-    QQuickMenuBar *menubar = qobject_cast<QQuickMenuBar *>(parent());
+    QQuickMenuBar1 *menubar = qobject_cast<QQuickMenuBar1 *>(parent());
     if (menubar && menubar->platformMenuBar())
         menubar->platformMenuBar()->syncMenu(m_platformMenu);
 }
 
-void QQuickMenu::setVisible(bool v)
+void QQuickMenu1::setVisible(bool v)
 {
-    QQuickMenuBase::setVisible(v);
+    QQuickMenuBase1::setVisible(v);
     if (m_platformMenu) {
         m_platformMenu->setVisible(v);
         syncParentMenuBar();
     }
 }
 
-void QQuickMenu::setEnabled(bool e)
+void QQuickMenu1::setEnabled(bool e)
 {
-    QQuickMenuText::setEnabled(e);
+    QQuickMenuText1::setEnabled(e);
     if (m_platformMenu) {
         m_platformMenu->setEnabled(e);
         syncParentMenuBar();
     }
 }
 
-void QQuickMenu::updateText()
+void QQuickMenu1::updateText()
 {
     if (m_platformMenu)
         m_platformMenu->setText(this->text());
-    QQuickMenuText::updateText();
+    QQuickMenuText1::updateText();
 }
 
-void QQuickMenu::setMinimumWidth(int w)
+void QQuickMenu1::setMinimumWidth(int w)
 {
     if (w == m_minimumWidth)
         return;
@@ -339,7 +348,7 @@ void QQuickMenu::setMinimumWidth(int w)
     emit minimumWidthChanged();
 }
 
-void QQuickMenu::setFont(const QFont &arg)
+void QQuickMenu1::setFont(const QFont &arg)
 {
     if (arg == m_font)
         return;
@@ -349,17 +358,17 @@ void QQuickMenu::setFont(const QFont &arg)
         m_platformMenu->setFont(arg);
 }
 
-void QQuickMenu::setXOffset(qreal x)
+void QQuickMenu1::setXOffset(qreal x)
 {
     m_xOffset = x;
 }
 
-void QQuickMenu::setYOffset(qreal y)
+void QQuickMenu1::setYOffset(qreal y)
 {
     m_yOffset = y;
 }
 
-void QQuickMenu::setSelectedIndex(int index)
+void QQuickMenu1::setSelectedIndex(int index)
 {
     if (m_selectedIndex == index)
         return;
@@ -368,21 +377,21 @@ void QQuickMenu::setSelectedIndex(int index)
     emit __selectedIndexChanged();
 }
 
-void QQuickMenu::updateSelectedIndex()
+void QQuickMenu1::updateSelectedIndex()
 {
-    if (QQuickMenuItem *menuItem = qobject_cast<QQuickMenuItem*>(sender())) {
+    if (QQuickMenuItem1 *menuItem = qobject_cast<QQuickMenuItem1*>(sender())) {
         int index = indexOfMenuItem(menuItem);
         setSelectedIndex(index);
     }
 }
 
-QQuickMenuItems QQuickMenu::menuItems()
+QQuickMenuItems QQuickMenu1::menuItems()
 {
-    return QQuickMenuItems(this, 0, &QQuickMenu::append_menuItems, &QQuickMenu::count_menuItems,
-                       &QQuickMenu::at_menuItems, &QQuickMenu::clear_menuItems);
+    return QQuickMenuItems(this, 0, &QQuickMenu1::append_menuItems, &QQuickMenu1::count_menuItems,
+                       &QQuickMenu1::at_menuItems, &QQuickMenu1::clear_menuItems);
 }
 
-QQuickWindow *QQuickMenu::findParentWindow()
+QQuickWindow *QQuickMenu1::findParentWindow()
 {
     if (!m_parentWindow) {
         QQuickItem *parentAsItem = qobject_cast<QQuickItem *>(parent());
@@ -392,7 +401,7 @@ QQuickWindow *QQuickMenu::findParentWindow()
     return m_parentWindow;
 }
 
-void QQuickMenu::popup()
+void QQuickMenu1::popup()
 {
     QQuickWindow *quickWindow = findParentWindow();
     QPoint renderOffset;
@@ -412,10 +421,10 @@ void QQuickMenu::popup()
     __popup(QRectF(mousePos.x() - renderOffset.x(), mousePos.y() - renderOffset.y(), 0, 0));
 }
 
-void QQuickMenu::__popup(const QRectF &targetRect, int atItemIndex, MenuType menuType)
+void QQuickMenu1::__popup(const QRectF &targetRect, int atItemIndex, MenuType menuType)
 {
     if (popupVisible()) {
-        __closeMenu();
+        hideMenu();
         // Mac and Windows would normally move the menu under the cursor, so we should not
         // return here. However, very often we want to re-contextualize the menu, and this
         // has to be done at the application level.
@@ -424,7 +433,7 @@ void QQuickMenu::__popup(const QRectF &targetRect, int atItemIndex, MenuType men
 
     setPopupVisible(true);
 
-    QQuickMenuBase *atItem = menuItemAtIndex(atItemIndex);
+    QQuickMenuBase1 *atItem = menuItemAtIndex(atItemIndex);
 
     QQuickWindow *quickWindow = findParentWindow();
     QPoint renderOffset;
@@ -445,7 +454,7 @@ void QQuickMenu::__popup(const QRectF &targetRect, int atItemIndex, MenuType men
         m_platformMenu->setMenuType(QPlatformMenu::MenuType(menuType));
         m_platformMenu->showPopup(parentWindow, globalTargetRect.toRect(), atItem ? atItem->platformItem() : 0);
     } else {
-        m_popupWindow = new QQuickMenuPopupWindow(this);
+        m_popupWindow = new QQuickMenuPopupWindow1(this);
         if (visualItem())
             m_popupWindow->setParentItem(visualItem());
         else
@@ -464,7 +473,7 @@ void QQuickMenu::__popup(const QRectF &targetRect, int atItemIndex, MenuType men
     }
 }
 
-void QQuickMenu::setMenuContentItem(QQuickItem *item)
+void QQuickMenu1::setMenuContentItem(QQuickItem *item)
 {
     if (m_menuContentItem != item) {
         m_menuContentItem = item;
@@ -472,7 +481,7 @@ void QQuickMenu::setMenuContentItem(QQuickItem *item)
     }
 }
 
-void QQuickMenu::setPopupVisible(bool v)
+void QQuickMenu1::setPopupVisible(bool v)
 {
     if (m_popupVisible != v) {
         m_popupVisible = v;
@@ -480,7 +489,7 @@ void QQuickMenu::setPopupVisible(bool v)
     }
 }
 
-QRect QQuickMenu::popupGeometry() const
+QRect QQuickMenu1::popupGeometry() const
 {
     if (!m_popupWindow || !m_popupVisible)
         return QRect();
@@ -488,22 +497,38 @@ QRect QQuickMenu::popupGeometry() const
     return m_popupWindow->geometry();
 }
 
-void QQuickMenu::__closeMenu()
+void QQuickMenu1::prepareItemTrigger(QQuickMenuItem1 *)
+{
+    m_triggerCount++;
+    __dismissMenu();
+}
+
+void QQuickMenu1::concludeItemTrigger(QQuickMenuItem1 *)
+{
+    if (--m_triggerCount == 0)
+        destroyAllMenuPopups();
+}
+
+/*!
+ * \internal
+ * Close this menu's popup window. Emits aboutToHide and sets __popupVisible to false.
+ */
+void QQuickMenu1::hideMenu()
 {
     if (m_popupVisible) {
         emit aboutToHide();
         setPopupVisible(false);
     }
-    if (m_popupWindow)
-        m_popupWindow->setVisible(false);
+    if (m_popupWindow && m_popupWindow->isVisible())
+        m_popupWindow->hide();
     m_parentWindow = 0;
 }
 
-QQuickMenuPopupWindow *QQuickMenu::topMenuPopup() const
+QQuickMenuPopupWindow1 *QQuickMenu1::topMenuPopup() const
 {
-    QQuickMenuPopupWindow *topMenuWindow = m_popupWindow;
+    QQuickMenuPopupWindow1 *topMenuWindow = m_popupWindow;
     while (topMenuWindow) {
-        QQuickMenuPopupWindow *pw = qobject_cast<QQuickMenuPopupWindow *>(topMenuWindow->transientParent());
+        QQuickMenuPopupWindow1 *pw = qobject_cast<QQuickMenuPopupWindow1 *>(topMenuWindow->transientParent());
         if (!pw)
             return topMenuWindow;
         topMenuWindow = pw;
@@ -512,50 +537,97 @@ QQuickMenuPopupWindow *QQuickMenu::topMenuPopup() const
     return 0;
 }
 
-void QQuickMenu::__dismissMenu()
+/*!
+ * \internal
+ * Dismiss all the menus this menu is attached to, bottom-up.
+ * In QQuickPopupWindow, before closing, dismissPopup() emits popupDismissed()
+ * which is connected to dismissPopup() on any child popup.
+ */
+void QQuickMenu1::__dismissMenu()
 {
     if (m_platformMenu) {
         m_platformMenu->dismiss();
-    } else if (QQuickMenuPopupWindow *topPopup = topMenuPopup()) {
+    } else if (QQuickMenuPopupWindow1 *topPopup = topMenuPopup()) {
         topPopup->dismissPopup();
     }
 }
 
-void QQuickMenu::windowVisibleChanged(bool v)
+/*!
+ * \internal
+ * Called when the popup window visible property changes.
+ */
+void QQuickMenu1::windowVisibleChanged(bool v)
 {
     if (!v) {
-        if (m_popupWindow && qobject_cast<QQuickMenuPopupWindow *>(m_popupWindow->transientParent())) {
-            m_popupWindow->transientParent()->setMouseGrabEnabled(true);
-            m_popupWindow->transientParent()->setKeyboardGrabEnabled(true);
+        if (m_popupWindow) {
+            QQuickMenuPopupWindow1 *parentMenuPopup = qobject_cast<QQuickMenuPopupWindow1 *>(m_popupWindow->transientParent());
+            if (parentMenuPopup) {
+                parentMenuPopup->setMouseGrabEnabled(true);
+                parentMenuPopup->setKeyboardGrabEnabled(true);
+            }
         }
-        __closeMenu();
+        if (m_popupVisible)
+            __closeAndDestroy();
     }
 }
 
-void QQuickMenu::clearPopupWindow()
+void QQuickMenu1::clearPopupWindow()
 {
     m_popupWindow = 0;
     emit __menuPopupDestroyed();
 }
 
-void QQuickMenu::__destroyMenuPopup()
+void QQuickMenu1::destroyMenuPopup()
 {
+    if (m_triggerCount > 0)
+        return;
     if (m_popupWindow)
         m_popupWindow->setToBeDeletedLater();
 }
 
-void QQuickMenu::__destroyAllMenuPopups() {
-    QQuickMenuPopupWindow *popup = topMenuPopup();
+void QQuickMenu1::destroyAllMenuPopups() {
+    if (m_triggerCount > 0)
+        return;
+    QQuickMenuPopupWindow1 *popup = topMenuPopup();
     if (popup)
         popup->setToBeDeletedLater();
 }
 
-void QQuickMenu::itemIndexToListIndex(int itemIndex, int *listIndex, int *containerIndex) const
+QQuickMenuBar1 *QQuickMenu1::menuBar()
+{
+    QObject *pi = parentMenuOrMenuBar();
+    while (pi) {
+        if (QQuickMenuBar1 *menuBar = qobject_cast<QQuickMenuBar1*>(pi))
+            return menuBar;
+        else if (QQuickMenu1 *menu = qobject_cast<QQuickMenu1*>(pi))
+            pi = menu->parentMenuOrMenuBar();
+        else
+            return 0;
+    }
+    return 0;
+}
+
+void QQuickMenu1::__closeAndDestroy()
+{
+    hideMenu();
+    destroyMenuPopup();
+}
+
+void QQuickMenu1::__dismissAndDestroy()
+{
+    if (m_platformMenu)
+        return;
+
+    __dismissMenu();
+    destroyAllMenuPopups();
+}
+
+void QQuickMenu1::itemIndexToListIndex(int itemIndex, int *listIndex, int *containerIndex) const
 {
     *listIndex = -1;
-    QQuickMenuItemContainer *container = 0;
+    QQuickMenuItemContainer1 *container = 0;
     while (itemIndex >= 0 && ++*listIndex < m_menuItems.count())
-        if ((container = qobject_cast<QQuickMenuItemContainer *>(m_menuItems[*listIndex])))
+        if ((container = qobject_cast<QQuickMenuItemContainer1 *>(m_menuItems[*listIndex])))
             itemIndex -= container->items().count();
         else
             --itemIndex;
@@ -566,12 +638,12 @@ void QQuickMenu::itemIndexToListIndex(int itemIndex, int *listIndex, int *contai
         *containerIndex = -1;
 }
 
-int QQuickMenu::itemIndexForListIndex(int listIndex) const
+int QQuickMenu1::itemIndexForListIndex(int listIndex) const
 {
     int index = 0;
     int i = 0;
     while (i < listIndex && i < m_menuItems.count())
-        if (QQuickMenuItemContainer *container = qobject_cast<QQuickMenuItemContainer *>(m_menuItems[i++]))
+        if (QQuickMenuItemContainer1 *container = qobject_cast<QQuickMenuItemContainer1 *>(m_menuItems[i++]))
             index += container->items().count();
         else
             ++index;
@@ -579,16 +651,16 @@ int QQuickMenu::itemIndexForListIndex(int listIndex) const
     return index;
 }
 
-QQuickMenuBase *QQuickMenu::nextMenuItem(QQuickMenu::MenuItemIterator *it) const
+QQuickMenuBase1 *QQuickMenu1::nextMenuItem(QQuickMenu1::MenuItemIterator *it) const
 {
     if (it->containerIndex != -1) {
-        QQuickMenuItemContainer *container = qobject_cast<QQuickMenuItemContainer *>(m_menuItems[it->index]);
+        QQuickMenuItemContainer1 *container = qobject_cast<QQuickMenuItemContainer1 *>(m_menuItems[it->index]);
         if (++it->containerIndex < container->items().count())
             return container->items()[it->containerIndex];
     }
 
     if (++it->index < m_menuItems.count()) {
-        if (QQuickMenuItemContainer *container = qobject_cast<QQuickMenuItemContainer *>(m_menuItems[it->index])) {
+        if (QQuickMenuItemContainer1 *container = qobject_cast<QQuickMenuItemContainer1 *>(m_menuItems[it->index])) {
             it->containerIndex = 0;
             return container->items()[0];
         } else {
@@ -600,20 +672,20 @@ QQuickMenuBase *QQuickMenu::nextMenuItem(QQuickMenu::MenuItemIterator *it) const
     return 0;
 }
 
-QQuickMenuBase *QQuickMenu::menuItemAtIndex(int index) const
+QQuickMenuBase1 *QQuickMenu1::menuItemAtIndex(int index) const
 {
     if (0 <= index && index < m_itemsCount) {
         if (!m_containersCount) {
             return m_menuItems[index];
         } else if (m_containersCount == 1 && m_menuItems.count() == 1) {
-            QQuickMenuItemContainer *container = qobject_cast<QQuickMenuItemContainer *>(m_menuItems[0]);
+            QQuickMenuItemContainer1 *container = qobject_cast<QQuickMenuItemContainer1 *>(m_menuItems[0]);
             return container->items()[index];
         } else {
             int containerIndex;
             int i;
             itemIndexToListIndex(index, &i, &containerIndex);
             if (containerIndex != -1) {
-                QQuickMenuItemContainer *container = qobject_cast<QQuickMenuItemContainer *>(m_menuItems[i]);
+                QQuickMenuItemContainer1 *container = qobject_cast<QQuickMenuItemContainer1 *>(m_menuItems[i]);
                 return container->items()[containerIndex];
             } else {
                 return m_menuItems[i];
@@ -624,7 +696,7 @@ QQuickMenuBase *QQuickMenu::menuItemAtIndex(int index) const
     return 0;
 }
 
-bool QQuickMenu::contains(QQuickMenuBase *item)
+bool QQuickMenu1::contains(QQuickMenuBase1 *item)
 {
     if (item->container())
         return item->container()->items().contains(item);
@@ -632,7 +704,7 @@ bool QQuickMenu::contains(QQuickMenuBase *item)
     return m_menuItems.contains(item);
 }
 
-int QQuickMenu::indexOfMenuItem(QQuickMenuBase *item) const
+int QQuickMenu1::indexOfMenuItem(QQuickMenuBase1 *item) const
 {
     if (!item)
         return -1;
@@ -648,37 +720,37 @@ int QQuickMenu::indexOfMenuItem(QQuickMenuBase *item) const
     }
 }
 
-QQuickMenuItem *QQuickMenu::addItem(QString title)
+QQuickMenuItem1 *QQuickMenu1::addItem(const QString &title)
 {
     return insertItem(m_itemsCount, title);
 }
 
-QQuickMenuItem *QQuickMenu::insertItem(int index, QString title)
+QQuickMenuItem1 *QQuickMenu1::insertItem(int index, const QString &title)
 {
-    QQuickMenuItem *item = new QQuickMenuItem(this);
+    QQuickMenuItem1 *item = new QQuickMenuItem1(this);
     item->setText(title);
     insertItem(index, item);
     return item;
 }
 
-void QQuickMenu::addSeparator()
+void QQuickMenu1::addSeparator()
 {
     insertSeparator(m_itemsCount);
 }
 
-void QQuickMenu::insertSeparator(int index)
+void QQuickMenu1::insertSeparator(int index)
 {
-    QQuickMenuSeparator *item = new QQuickMenuSeparator(this);
+    QQuickMenuSeparator1 *item = new QQuickMenuSeparator1(this);
     insertItem(index, item);
 }
 
-void QQuickMenu::insertItem(int index, QQuickMenuBase *menuItem)
+void QQuickMenu1::insertItem(int index, QQuickMenuBase1 *menuItem)
 {
     if (!menuItem)
         return;
     int itemIndex;
     if (m_containersCount) {
-        QQuickMenuItemContainer *container = menuItem->parent() != this ? m_containers[menuItem->parent()] : 0;
+        QQuickMenuItemContainer1 *container = menuItem->parent() != this ? m_containers[menuItem->parent()] : 0;
         if (container) {
             container->insertItem(index, menuItem);
             itemIndex = itemIndexForListIndex(m_menuItems.indexOf(container)) + index;
@@ -695,13 +767,13 @@ void QQuickMenu::insertItem(int index, QQuickMenuBase *menuItem)
     emit itemsChanged();
 }
 
-void QQuickMenu::removeItem(QQuickMenuBase *menuItem)
+void QQuickMenu1::removeItem(QQuickMenuBase1 *menuItem)
 {
     if (!menuItem)
         return;
     menuItem->setParentMenu(0);
 
-    QQuickMenuItemContainer *container = menuItem->parent() != this ? m_containers[menuItem->parent()] : 0;
+    QQuickMenuItemContainer1 *container = menuItem->parent() != this ? m_containers[menuItem->parent()] : 0;
     if (container)
         container->removeItem(menuItem);
     else
@@ -711,17 +783,22 @@ void QQuickMenu::removeItem(QQuickMenuBase *menuItem)
     emit itemsChanged();
 }
 
-void QQuickMenu::clear()
+void QQuickMenu1::clear()
 {
     m_containers.clear();
     m_containersCount = 0;
 
+    // QTBUG-48927: a proxy menu (ApplicationWindowStyle.qml) must not
+    // delete its items, because they are owned by the menubar
+    if (m_proxy)
+        m_menuItems.clear();
+
     while (!m_menuItems.empty())
         delete m_menuItems.takeFirst();
     m_itemsCount = 0;
 }
 
-void QQuickMenu::setupMenuItem(QQuickMenuBase *item, int platformIndex)
+void QQuickMenu1::setupMenuItem(QQuickMenuBase1 *item, int platformIndex)
 {
     item->setParentMenu(this);
     if (m_platformMenu) {
@@ -733,20 +810,21 @@ void QQuickMenu::setupMenuItem(QQuickMenuBase *item, int platformIndex)
     ++m_itemsCount;
 }
 
-void QQuickMenu::append_menuItems(QQuickMenuItems *list, QObject *o)
+void QQuickMenu1::append_menuItems(QQuickMenuItems *list, QObject *o)
 {
-    if (QQuickMenu *menu = qobject_cast<QQuickMenu *>(list->object)) {
-        if (QQuickMenuBase *menuItem = qobject_cast<QQuickMenuBase *>(o)) {
+    if (QQuickMenu1 *menu = qobject_cast<QQuickMenu1 *>(list->object)) {
+        if (QQuickMenuBase1 *menuItem = qobject_cast<QQuickMenuBase1 *>(o)) {
             menu->m_menuItems.append(menuItem);
             menu->setupMenuItem(menuItem);
         } else {
-            QQuickMenuItemContainer *menuItemContainer = new QQuickMenuItemContainer(menu);
+            QQuickMenuItemContainer1 *menuItemContainer = new QQuickMenuItemContainer1(menu);
             menu->m_menuItems.append(menuItemContainer);
             menu->m_containers.insert(o, menuItemContainer);
             menuItemContainer->setParentMenu(menu);
             ++menu->m_containersCount;
-            foreach (QObject *child, o->children()) {
-                if (QQuickMenuBase *item = qobject_cast<QQuickMenuBase *>(child)) {
+            const auto children = o->children();
+            for (QObject *child : children) {
+                if (QQuickMenuBase1 *item = qobject_cast<QQuickMenuBase1 *>(child)) {
                     menuItemContainer->insertItem(-1, item);
                     menu->setupMenuItem(item);
                 }
@@ -755,25 +833,25 @@ void QQuickMenu::append_menuItems(QQuickMenuItems *list, QObject *o)
     }
 }
 
-int QQuickMenu::count_menuItems(QQuickMenuItems *list)
+int QQuickMenu1::count_menuItems(QQuickMenuItems *list)
 {
-    if (QQuickMenu *menu = qobject_cast<QQuickMenu *>(list->object))
+    if (QQuickMenu1 *menu = qobject_cast<QQuickMenu1 *>(list->object))
         return menu->m_itemsCount;
 
     return 0;
 }
 
-QObject *QQuickMenu::at_menuItems(QQuickMenuItems *list, int index)
+QObject *QQuickMenu1::at_menuItems(QQuickMenuItems *list, int index)
 {
-    if (QQuickMenu *menu = qobject_cast<QQuickMenu *>(list->object))
+    if (QQuickMenu1 *menu = qobject_cast<QQuickMenu1 *>(list->object))
         return menu->menuItemAtIndex(index);
 
     return 0;
 }
 
-void QQuickMenu::clear_menuItems(QQuickMenuItems *list)
+void QQuickMenu1::clear_menuItems(QQuickMenuItems *list)
 {
-    if (QQuickMenu *menu = qobject_cast<QQuickMenu *>(list->object))
+    if (QQuickMenu1 *menu = qobject_cast<QQuickMenu1 *>(list->object))
         menu->clear();
 }
 
